@@ -222,6 +222,6 @@ namespace gum {
 } /* namespace gum */
 
 // always include the implementations
-#include <agrum/multidim/operators/operatorRegister4MultiDim.tcc>
+#include <agrum/multidim/operators/operatorRegister4MultiDim_tpl.h>
 
 #endif /* GUM_OPERATOR_REGISTER_MULTI_DIM_H */
