@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-# (c) Copyright by Pierre-Henri Wuillemin, UPMC, 2012
+# (c) Copyright by Pierre-Henri Wuillemin, UPMC, 2017
 # (pierre-henri.wuillemin@lip6.fr)
 # Permission to use, copy, modify, and distribute this
 # software and its documentation for any purpose and
@@ -20,15 +20,14 @@
 # OR PERFORMANCE OF THIS SOFTWARE!
 
 """
-tools for BN analysis in jupyter notebook (but can be used everywhere)
+tools for BN analysis in jupyter notebook
 """
 from __future__ import print_function
 
-import base64
-import shutil
 import time
 
 import IPython.display
+import base64
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import numpy as np
@@ -38,8 +37,19 @@ from IPython.core.display import Image, display_png
 from IPython.core.pylabtools import print_figure
 from IPython.display import display, HTML, SVG
 from matplotlib.backends.backend_agg import FigureCanvasAgg as fc
+from pyAgrum.lib.bn2graph import BN2dot, proba2histo, BNinference2dot,_proba2bgcolor
 
 
+_cdict = {
+  'red'  : ((0.0, 0.1, 0.3),
+            (1.0, 0.6, 1.0)),
+  'green': ((0.0, 0.0, 0.0),
+            (1.0, 0.6, 0.8)),
+  'blue' : ((0.0, 0.0, 0.0),
+            (1.0, 1, 0.8))
+}
+_INFOcmap = mpl.colors.LinearSegmentedColormap('my_colormap', _cdict, 256)
+
 def configuration():
   """
   Display the collection of dependance and versions
@@ -63,7 +73,7 @@ def configuration():
   res += "</table><div align='right'><small>%s</small></div>" % time.strftime(
       '%a %b %d %H:%M:%S %Y %Z')
 
-  return IPython.display.HTML(res)
+  display(HTML(res))
 
 
 def _reprGraph(gr, size, format, asString):
@@ -197,77 +207,6 @@ def getInfluenceDiagram(diag, size="4", format="png"):
   return getDot(diag.toDot(), size, format)
 
 
-def _getProbaV(p):
-  """
-  compute the representation of an histogram for a mono-dim Potential
-
-  :param p: the mono-dim Potential
-  :return: a matplotlib bar (vertical histogram) for a Potential p.
-
-  """
-  var = p.variable(0)
-  ra = np.arange(var.domainSize())
-
-  fig = plt.figure()
-  fig.set_figwidth(var.domainSize() / 4.0)
-  fig.set_figheight(2)
-
-  ax = fig.add_subplot(111)
-
-  ax.bar(ra, p.tolist(), align='center')
-  # ax.set_ylim(0,1)
-  ax.set_xticks(ra)
-  ax.set_xticklabels([])
-  # ax.set_xlabel('Probability')
-  ax.set_title(var.name())
-  ax.get_yaxis().grid(True)
-  return fig
-
-
-def _getProbaH(p):
-  """
-  compute the representation of an histogram for a mono-dim Potential
-
-  :param p: the mono-dim Potential
-  :return: a matplotlib barh (horizontal histogram) for a Potential p.
-  """
-  var = p.variable(0)
-  ra = np.arange(var.domainSize())
-  ra_reverse = np.arange(var.domainSize() - 1, -1, -1)  # reverse order
-  vx = ["{0}:{1:1.4f}".format(var.label(int(i)), p[i]) for i in ra_reverse]
-
-  fig = plt.figure()
-  fig.set_figheight(var.domainSize() / 4.0)
-  fig.set_figwidth(2)
-
-  ax = fig.add_subplot(111)
-
-  vals = p.tolist()
-  vals.reverse()
-  ax.barh(ra, vals, align='center')
-  ax.set_xlim(0, 1)
-  ax.set_yticks(np.arange(var.domainSize()))
-  ax.set_yticklabels(vx)
-  ax.set_xticklabels([])
-  # ax.set_xlabel('Probability')
-  ax.set_title(var.name())
-  ax.get_xaxis().grid(True)
-  return fig
-
-
-def getProba(p):
-  """
-  compute the representation of an histogram for a mono-dim Potential
-
-  :param p: the mono-dim Potential
-  :return: a matplotlib histogram for a Potential p.
-  """
-  if p.variable(0).domainSize() > 8:
-    return _getProbaV(p)
-  else:
-    return _getProbaH(p)
-
-
 def showProba(p):
   """
   Show a mono-dim Potential
@@ -275,12 +214,12 @@ def showProba(p):
   :param p: the mono-dim Potential
   :return:
   """
-  fig = getProba(p)
+  fig = proba2histo(p)
   plt.show()
 
 
 def _saveFigProba(p, filename, format="svg"):
-  fig = getProba(p)
+  fig = proba2histo(p)
   fig.savefig(filename, bbox_inches='tight', transparent=True, pad_inches=0, dpi=fig.dpi, format=format)
   plt.close(fig)
 
@@ -297,7 +236,7 @@ def getPosterior(bn, evs, target):
   :type target: str
   :return: the matplotlib graph
   """
-  return getProba(gum.getPosterior(bn, evs, target))
+  return proba2histo(gum.getPosterior(bn, evs=evs, target=target))
 
 
 def showPosterior(bn, evs, target):
@@ -308,7 +247,7 @@ def showPosterior(bn, evs, target):
   :param evs: map of evidence
   :param target: name of target variable
   """
-  showProba(gum.getPosterior(bn, evs, target))
+  showProba(gum.getPosterior(bn, evs=evs, target=target))
 
 
 def animApproximationScheme(apsc, scale=np.log10):
@@ -321,7 +260,7 @@ def animApproximationScheme(apsc, scale=np.log10):
   from IPython.display import clear_output, display
   f = plt.gcf()
 
-  h = gum.PythonApproximationListener(apsc)
+  h = gum.PythonApproximationListener(apsc.asIApproximationSchemeConfiguration())
   apsc.setVerbosity(True)
   apsc.listener = h
 
@@ -344,71 +283,7 @@ def animApproximationScheme(apsc, scale=np.log10):
   h.setWhenProgress(progresser)
 
 
-_cdict = {'red'  : ((0.0, 0.1, 0.3),
-                    (1.0, 0.6, 1.0)),
-          'green': ((0.0, 0.0, 0.0),
-                    (1.0, 0.6, 0.8)),
-          'blue' : ((0.0, 0.0, 0.0),
-                    (1.0, 1, 0.8))}
-_INFOcmap = mpl.colors.LinearSegmentedColormap('my_colormap', _cdict, 256)
-
-
-def _proba2rgb(p=0.99, cmap=_INFOcmap):
-  if p == 0.0:
-    r, g, b = "FF", "33", "33"
-  elif p == 1.0:
-    r, g, b = "AA", "FF", "FF"
-  else:
-    (r, g, b, _) = cmap(p)
-    r = "%02x" % int(r * 256)
-    g = "%02x" % int(g * 256)
-    b = "%02x" % int(b * 256)
-
-  return r, g, b
-
-
-def _proba2bgcolor(p, cmap=_INFOcmap):
-  r, g, b = _proba2rgb(p, cmap)
-  return "#" + r + g + b
-
-
-def _proba2fgcolor(p, cmap=_INFOcmap):
-  if max([eval("0x" + s[0]) for s in _proba2rgb(p, cmap)]) <= 12:
-    return "#FFFFFF"
-  else:
-    return "#000000"
-
-
-def _BN2colouredDot(bn, size="4", vals=None, cmap=_INFOcmap):
-  """
-  Shows a graphviz svg representation of the BN using size ("1" ,"2" , ...)
-  vals is a dictionnary name:value of value in [0,1] for each node
-  (with special color for 0 and 1)
-  """
-  graph = dot.Dot(graph_type='digraph')
-  for n in bn.names():
-    if vals is None or n not in vals:
-      bgcol = "#444444"
-      fgcol = "#FFFFFF"
-      res = ""
-    else:
-      bgcol = _proba2bgcolor(vals[n], cmap)
-      fgcol = _proba2fgcolor(vals[n], cmap)
-      res = " : {0:2.5f}".format(vals[n])
-
-    node = dot.Node('"' + n + '"', style="filled",
-                    fillcolor=bgcol,
-                    fontcolor=fgcol,
-                    tooltip='"({0}) {1}{2}"'.format(bn.idFromName(n), n, res))
-    graph.add_node(node)
-  for a in bn.arcs():
-    edge = dot.Edge('"' + bn.variable(a[0]).name() + '"', '"' + bn.variable(a[1]).name() + '"')
-    graph.add_edge(edge)
-  graph.set_size(size)
-  return graph
-
-
-def showBN(bn, size="4", format="svg", vals=None, cmap=_INFOcmap, asString=False):
+def showBN(bn, size="4", format="svg", arcvals=None, vals=None, cmap=None):
   """
   show a Bayesian network
 
@@ -416,13 +291,14 @@ def showBN(bn, size="4", format="svg", vals=None, cmap=_INFOcmap, asString=False
   :param size: size of the rendered graph
   :param format: render as "png" or "svg"
   :param vals: a nodeMap of values to be shown as color nodes
+  :param arcvals: a arcMap of values to be shown as bold arcs
   :param cmap: color map to show the vals
   :return: the graph
   """
-  return showGraph(_BN2colouredDot(bn, size, vals, cmap), size, format)
+  return showGraph(BN2dot(bn, size, arcvals, vals, cmap), size, format)
 
 
-def getBN(bn, size="4", format="svg", vals=None, cmap=_INFOcmap, asString=False):
+def getBN(bn, size="4", format="svg", arcvals=None, vals=None, cmap=None):
   """
   get a HTML string for a Bayesian network
 
@@ -430,10 +306,11 @@ def getBN(bn, size="4", format="svg", vals=None, cmap=_INFOcmap, asString=False)
   :param size: size of the rendered graph
   :param format: render as "png" or "svg"
   :param vals: a nodeMap of values to be shown as color nodes
+  :param arcvals: a arcMap of values to be shown as bold arcs
   :param cmap: color map to show the vals
   :return: the graph
   """
-  return getGraph(_BN2colouredDot(bn, size, vals, cmap), size, format)
+  return getGraph(BN2dot(bn, size, arcvals, vals, cmap), size, format)
 
 
 def _normalizeVals(vals, hilightExtrema=False):
@@ -460,19 +337,27 @@ def _normalizeVals(vals, hilightExtrema=False):
     return {name: vmi + (val - mi) * (vma - vmi) / (ma - mi) for name, val in items}
 
 
-def _reprEntropy(bn, evs, size, cmap, asString):
+def _reprInformation(bn, evs, size, cmap, asString):
   """
-  Shows a
+  repr a bn annoted with results from inference : Information and mutual informations
+
+  :param bn: the BN
+  :param evs: map of evidence
+  :param size:  size of the graph
+  :param cmap: colour map used
+  :return: the HTML string
   """
   ie = gum.LazyPropagation(bn)
   ie.setEvidence(evs)
   ie.makeInference()
 
-  vals = {bn.variable(n).name(): ie.H(n) for n in bn.ids()}
-  gr = _BN2colouredDot(bn, size, _normalizeVals(vals, hilightExtrema=False), cmap)
+  idEvs = {bn.idFromName(name) for name in evs}
+  nodevals = {bn.variable(n).name(): ie.H(n) for n in bn.ids() if not n in idEvs}
+  arcvals = {(x, y): ie.I(x, y) for x, y in bn.arcs()}
+  gr = BN2dot(bn, size, arcvals, _normalizeVals(nodevals, hilightExtrema=False), cmap, showValues=nodevals)
 
-  mi = min(vals.values())
-  ma = max(vals.values())
+  mi = min(nodevals.values())
+  ma = max(nodevals.values())
 
   fig = mpl.figure.Figure(figsize=(8, 3))
   canvas = fc(fig)
@@ -501,7 +386,7 @@ def _reprEntropy(bn, evs, size, cmap, asString):
     return display(HTML(sss))
 
 
-def getEntropy(bn, evs={}, size="4", cmap=_INFOcmap):
+def getInformation(bn, evs={}, size="4", cmap=_INFOcmap):
   """
   get a HTML string for a bn annoted with results from inference : entropy and mutual informations
 
@@ -511,10 +396,10 @@ def getEntropy(bn, evs={}, size="4", cmap=_INFOcmap):
   :param cmap: colour map used
   :return: the HTML string
   """
-  return _reprEntropy(bn, evs, size, cmap, asString=True)
+  return _reprInformation(bn, evs, size, cmap, asString=True)
 
 
-def showEntropy(bn, evs={}, size="4", cmap=_INFOcmap):
+def showInformation(bn, evs={}, size="4", cmap=_INFOcmap):
   """
   show a bn annoted with results from inference : entropy and mutual informations
 
@@ -524,60 +409,10 @@ def showEntropy(bn, evs={}, size="4", cmap=_INFOcmap):
   :param cmap: colour map used
   :return: the graph
   """
-  return _reprEntropy(bn, evs, size, cmap, asString=False)
+  return _reprInformation(bn, evs, size, cmap, asString=False)
 
 
-def _reprInference(bn, engine, evs, targets, size, format, asString):
-  """
-  repr a pydot graph for an inference in a notebook
-
-  :param gum.BayesNet bn:
-  :param gum.Inference engine: inference algorithm used. If None, LazyPropagation will be used
-  :param dictionnary evs: map of evidence
-  :param set targets: set of targets. If targets={} then each node is a target
-  :param string size: size of the rendered graph
-  :param string format: render as "png" or "svg"
-  :param boolean asString: display the graph or return a string containing the corresponding HTML fragment
-  :return: the desired representation of the inference
-  """
-  startTime = time.time()
-  if engine is None:
-    ie = gum.LazyPropagation(bn)
-  else:
-    ie = engine
-  ie.setEvidence(evs)
-  ie.makeInference()
-  stopTime = time.time()
-
-  from tempfile import mkdtemp
-  temp_dir = mkdtemp("", "tmp", None)  # with TemporaryDirectory() as temp_dir:
-
-  dotstr = "digraph structs {\n"
-  dotstr += "  label=\"Inference in {:6.2f}ms\";\n".format(1000 * (stopTime - startTime))
-  dotstr += "  node [fillcolor=floralwhite, style=filled,color=grey];\n"
-
-  for i in bn.ids():
-    name = bn.variable(i).name()
-    if len(targets) == 0 or name in targets:
-      filename = temp_dir + name + "." + format
-      _saveFigProba(ie.posterior(i), filename, format=format)
-      fill = ", fillcolor=sandybrown" if name in evs else ""
-      dotstr += ' "{0}" [shape=rectangle,image="{1}",label="" {2}];\n'.format(name, filename, fill)
-    else:
-      fill = "[fillcolor=sandybrown]" if name in evs else ""
-      dotstr += ' "{0}" {1}'.format(name, fill)
-  for (i, j) in bn.arcs():
-    dotstr += ' "{0}"->"{1}";'.format(bn.variable(i).name(), bn.variable(j).name())
-  dotstr += '}'
-
-  g = dot.graph_from_dot_data(dotstr)
-  sss = _reprGraph(g, size=size, format=format, asString=asString)
-
-  shutil.rmtree(temp_dir)
-  return sss
-
-
-def showInference(bn, engine=None, evs={}, targets={}, size="7", format='png'):
+def showInference(bn, engine=None, evs={}, targets={}, size="7", format='png', vals=None, arcvals=None, cmap=None):
   """
   show pydot graph for an inference in a notebook
 
@@ -590,10 +425,10 @@ def showInference(bn, engine=None, evs={}, targets={}, size="7", format='png'):
   :param boolean asString: display the graph or return a string containing the corresponding HTML fragment
   :return: the desired representation of the inference
   """
-  return _reprInference(bn, engine, evs, targets, size, format, asString=False)
+  return showGraph(BNinference2dot(bn, size, engine, evs, targets, format, vals, arcvals, cmap), size, format)
 
 
-def getInference(bn, engine=None, evs={}, targets={}, size="7", format='png'):
+def getInference(bn, engine=None, evs={}, targets={}, size="7", format='png', vals=None, arcvals=None, cmap=None):
   """
   get a HTML string for an inference in a notebook
 
@@ -606,72 +441,98 @@ def getInference(bn, engine=None, evs={}, targets={}, size="7", format='png'):
   :param boolean asString: display the graph or return a string containing the corresponding HTML fragment
   :return: the desired representation of the inference
   """
-  return _reprInference(bn, engine, evs, targets, size, format, asString=True)
+  return getGraph(BNinference2dot(bn, size, engine, evs, targets, format, vals, arcvals, cmap), size, format)
 
 
-def _reprPotential(pot, digits, varnames, asString):
+def _reprPotential(pot, digits=4, withColors=True, varnames=None, asString=False):
   """
   return a representation of a gum.Potential as a HTML table.
   The first dimension is special (horizontal) due to the representation of conditional probability table
 
-  :param gum.Potential pot:
-  :param int digits: number of digits to show
-  :param list varnames: the aliases for variables name in the table
-  :param boolean asString: display the table or a HTML string
+
+  :param pot: the potential to get
+  :param digits: number of digits to show
+  :param: withColors : bgcolor for proba cells or not
+  :param varnames: the aliases for variables name in the table
+  :param asString: display the table or a HTML string
   :return: the representation
   """
   from IPython.core.display import HTML
 
+  def _rgb(r, g, b):
+    return '#%02x%02x%02x' % (r, g, b)
+
+  def _mkCell(val):
+    s = "<td style='"
+    if withColors and (0 <= val <= 1):
+      r = int(255 - val * 128)
+      g = int(127 + val * 128)
+      b = 100
+      s += "background-color:" + _rgb(r, g, b) + ";"
+    s += "text-align:right;'>{:." + str(digits) + "f}</td>"
+    return s.format(val)
+
   html = list()
   html.append("<table>")
-
-  if varnames is not None and len(varnames) != pot.nbrDim():
-    raise ValueError("varnames contains {} values instead of the needed {} values.".format(len(varnames), pot.nbrDim()))
-
-  nparents = pot.nbrDim() - 1
-  var = pot.variable(0)
-  varname = var.name() if varnames == None else varnames[0]
-
-  # first line
-  if nparents > 0:
-    html.append(
-        "<tr><th colspan='{}'></th><th colspan='{}' style='background-color:#AAAAAA'><center>{}</center></th></tr>".format(
-            nparents, var.domainSize(), varname))
+  if pot.empty():
+    html.append("<tr><th style='background-color:#AAAAAA'>&nbsp;</th></tr>")
+    html.append("<tr>" + _mkCell(pot.get(gum.Instantiation())) + "</tr>")
   else:
-    html.append(
-        "<tr style='background-color:#AAAAAA'><th colspan='{}'><center>{}</center></th></tr>".format(var.domainSize(),
-                                                                                                     varname))
-  # second line
-  html.append("<tr>")
-  if nparents > 0:
-    for parent in pot.var_names[:-1] if varnames == None else varnames[1:]:
-      html.append("<th style='background-color:#AAAAAA'><center>{}</center></th>".format(parent))
-  for label in var.labels():
-    html.append("<th style='background-color:#BBBBBB'><center>{}</center></th>".format(label))
+    if varnames is not None and len(varnames) != pot.nbrDim():
+      raise ValueError(
+          "varnames contains {} values instead of the needed {} values.".format(len(varnames), pot.nbrDim()))
 
-  inst = gum.Instantiation(pot)
-  off = 1
-  offset = dict()
-  for i in range(1, nparents + 1):
-    offset[i] = off
-    off *= inst.variable(i).domainSize()
+    nparents = pot.nbrDim() - 1
+    var = pot.variable(0)
+    varname = var.name() if varnames == None else varnames[0]
 
-  html.append("<tr>")
-  inst.setFirst()
-  while not inst.end():
-    if inst.val(0) == 0:
-      for par in range(nparents, 0, -1):
+    # first line
+    if nparents > 0:
+      html.append(
+          "<tr><th colspan='{}'></th><th colspan='{}' style='background-color:#AAAAAA'><center>{"
+          "}</center></th></tr>".format(
+              nparents, var.domainSize(), varname))
+    else:
+      html.append(
+          "<tr style='background-color:#AAAAAA'><th colspan='{}'><center>{}</center></th></tr>".format(
+              var.domainSize(),
+              varname))
+    # second line
+    s = "<tr>"
+    if nparents > 0:
+      # for parent in pot.var_names[:-1] if varnames == None else varnames[1:]:
+      for par in range(nparents - 1, 0 - 1, -1):
+        parent = pot.var_names[par] if varnames is None else varnames[par]
+        s += "<th style='background-color:#AAAAAA'><center>{}</center></th>".format(parent)
+    for label in var.labels():
+      s += "<th style='background-color:#BBBBBB'><center>{}</center></th>".format(label)
+    s += '</tr>'
+
+    html.append(s)
+
+    inst = gum.Instantiation(pot)
+    off = 1
+    offset = dict()
+    for i in range(1, nparents + 1):
+      offset[i] = off
+      off *= inst.variable(i).domainSize()
+
+    inst.setFirst()
+    while not inst.end():
+      s = "<tr>"
+      for par in range(1, nparents + 1):
         label = inst.variable(par).label(inst.val(par))
         if par == 1:
-          html.append("<th style='background-color:#BBBBBB'>{}</th>".format(label))
+          s += "<th style='background-color:#BBBBBB'><center>{}</center></th>".format(label)
         else:
           if sum([inst.val(i) for i in range(1, par)]) == 0:
-            html.append("<th style='background-color:#BBBBBB;' rowspan = '{}'>{}</th>".format(offset[par], label))
-    html.append(("<td style='text-align:right;'>{:." + str(digits) + "f}</td>").format(pot.get(inst)))
-    inst.inc()
-    if not inst.end() and inst.val(0) == 0:
-      html.append("</tr><tr>")
-  html.append("</tr>")
+            s += "<th style='background-color:#BBBBBB;' rowspan = '{}'><center>{}</center></th>".format(offset[par],
+                                                                                                        label)
+      for j in range(pot.variable(0).domainSize()):
+        s += _mkCell(pot.get(inst))
+        inst.inc()
+      s += "</tr>"
+      html.append(s)
 
   html.append("</table>")
 
@@ -681,33 +542,32 @@ def _reprPotential(pot, digits, varnames, asString):
     return HTML("".join(html))
 
 
-def showPotential(pot, digits=4, varnames=None):
+def showPotential(pot, digits=4, withColors=True, varnames=None):
   """
   show a gum.Potential as a HTML table.
   The first dimension is special (horizontal) due to the representation of conditional probability table
 
-  :param gum.Potential pot:
+  :param gum.Potential pot: the potential to get  
   :param int digits: number of digits to show
-  :param list varnames: the aliases for variables name in the table
+  :param: boolean withColors : bgcolor for proba cells or not
+  :param list of strings varnames: the aliases for variables name in the table
   :return: the display of the potential
   """
-  return _reprPotential(pot, digits, varnames, asString=False)
+  display(_reprPotential(pot, digits, withColors, varnames, asString=False))
 
 
-def getPotential(pot, digits=4, varnames=None):
+def getPotential(pot, digits=4, withColors=True, varnames=None):
   """
   return a HTML string of a gum.Potential as a HTML table.
   The first dimension is special (horizontal) due to the representation of conditional probability table
 
-  :param pot: the potential to get
-  :type pot: gum.Potential
-  :param digits: number of digits to show
-  :type digits: int
-  :param varnames: the aliases for variables name in the table
-  :type varnames: list of strings
+  :param gum.Potential pot: the potential to get  
+  :param int digits: number of digits to show
+  :param: boolean withColors : bgcolor for proba cells or not
+  :param list of strings varnames: the aliases for variables name in the table
   :return: the HTML string
   """
-  return _reprPotential(pot, digits, varnames, asString=True)
+  return _reprPotential(pot, digits, withColors, varnames, asString=True)
 
 
 def getSideBySide(*args, **kwargs):
@@ -771,34 +631,35 @@ def getInferenceEngine(ie, inferenceCaption):
   """
   display an inference as a BN+ lists of hard/soft evidence and list of targets
 
-  :param ie:
+  :param gum.InferenceEngine ie: inference engine
+  :param string inferenceCaption : title for caption
   """
   t = '<div align="left"><ul>'
   if ie.nbrHardEvidence() > 0:
     t += "<li><b>hard evidence</b><br/>"
-    t += ", ".join([ie.BayesNet().variable(n).name() for n in ie.hardEvidenceList()])
+    t += ", ".join([ie.BN().variable(n).name() for n in ie.hardEvidenceList()])
     t += "</li>"
   if ie.nbrSoftEvidence() > 0:
     t += "<li><b>soft evidence</b><br/>"
-    t += ", ".join([ie.BayesNet().variable(n).name() for n in ie.softEvidenceList()])
+    t += ", ".join([ie.BN().variable(n).name() for n in ie.softEvidenceList()])
     t += "</li>"
   if ie.nbrTargets() > 0:
     t += "<li><b>target(s)</b><br/>"
-    if ie.nbrTargets() == ie.BayesNet().size():
+    if ie.nbrTargets() == ie.BN().size():
       t += " all"
     else:
-      t += ", ".join([ie.BayesNet().variable(n).name() for n in ie.targetList()])
+      t += ", ".join([ie.BN().variable(n).name() for n in ie.targetList()])
     t += "</li>"
 
   if hasattr(ie, 'nbrJointTargets'):
     if ie.nbrJointTargets() > 0:
       t += "<li><b>Joint target(s)</b><br/>"
       t += ", ".join(['['
-                      + (", ".join([ie.BayesNet().variable(n).name() for n in ns]))
+                      + (", ".join([ie.BN().variable(n).name() for n in ns]))
                       + ']' for ns in ie.jointTargets()])
       t += "</li>"
   t += '</ul></div>'
-  return getSideBySide(getBN(ie.BayesNet()), t, captions=[inferenceCaption, "Evidence and targets"])
+  return getSideBySide(getBN(ie.BN()), t, captions=[inferenceCaption, "Evidence and targets"])
 
 
 # adding _repr_html_ to some pyAgrum classes !
